summaryrefslogtreecommitdiffstats
path: root/chrome/browser/profiles/profile_dependency_manager.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/profiles/profile_dependency_manager.cc')
-rw-r--r--chrome/browser/profiles/profile_dependency_manager.cc7
1 files changed, 3 insertions, 4 deletions
diff --git a/chrome/browser/profiles/profile_dependency_manager.cc b/chrome/browser/profiles/profile_dependency_manager.cc
index 6b54a76..71468fd 100644
--- a/chrome/browser/profiles/profile_dependency_manager.cc
+++ b/chrome/browser/profiles/profile_dependency_manager.cc
@@ -21,7 +21,6 @@
#include "chrome/browser/search_engines/template_url_service_factory.h"
#include "chrome/browser/sessions/session_service_factory.h"
#include "chrome/browser/sessions/tab_restore_service_factory.h"
-#include "chrome/browser/signin/signin_manager_factory.h"
#include "chrome/browser/speech/speech_input_extension_manager.h"
#include "chrome/browser/sync/profile_sync_service_factory.h"
@@ -77,9 +76,10 @@ void ProfileDependencyManager::CreateProfileServices(Profile* profile,
for (std::vector<ProfileKeyedServiceFactory*>::reverse_iterator rit =
destruction_order_.rbegin(); rit != destruction_order_.rend();
++rit) {
- if (!profile->IsOffTheRecord()) {
+ if (!profile->IsOffTheRecord() && !profile->AsTestingProfile()) {
// We only register preferences on normal profiles because the incognito
// profile shares the pref service with the normal one.
(*rit)->RegisterUserPrefsOnProfile(profile);
}
@@ -156,7 +156,6 @@ void ProfileDependencyManager::AssertFactoriesBuilt() {
prerender::PrerenderManagerFactory::GetInstance();
ProfileSyncServiceFactory::GetInstance();
SessionServiceFactory::GetInstance();
- SigninManagerFactory::GetInstance();
SpeechInputExtensionManager::InitializeFactory();
TabRestoreServiceFactory::GetInstance();
TemplateURLServiceFactory::GetInstance();
@@ -77,9 +76,10 @@ void ProfileDependencyManager::CreateProfileServices(Profile* profile,
// We only register preferences on normal profiles because the incognito
- // profile shares the pref service with the normal one.
+ // profile shares the pref service with the normal one and the testing
+ // profile will often just insert its own PrefService.
(*rit)->RegisterUserPrefsOnProfile(profile);
}